###########################################################################
#
# jSongMinerExtractor - helper plugin that identifies audio through
#                       external web services based on either an audio
#                       computed fingerprint or ID3 title and album
#
# A component of the Greenstone digital library software
# from the New Zealand Digital Library Project at the 
# University of Waikato, New Zealand.
#
# Copyright (C) 2010 New Zealand Digital Library Project
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#
###########################################################################
package jSongMinerExtractor;

use BaseMediaConverter;

use Cwd;

use strict;
no strict 'refs'; # allow filehandles to be variables and viceversa


BEGIN {
    @jSongMinerExtractor::ISA = ('BaseMediaConverter');
}


my $arguments = [
    { 'name' => "track_identification",
      'desc' => "{jSongMinerExtractor.track_identification}",
      'type' => "enum",
      'list' => [{'name' => "Fingerprint then ID3 tags", 'desc' => "{jSongMinerExtractor.fingerprint_first}"},
		 {'name' => "ID3 tags only", 'desc' => "{jSongMinerExtractor.only_ids}"},
		 {'name' => "Disabled",     'desc' => "{jSongMinerExtractor.off}"} ],
      'deft' => 'Fingerprint then ID3 tags',
      'reqd' => "no" }
    ];

my $options = { 'name' => "jSongMinerExtractor",
		'desc' => "{jSongMinerExtractor.desc}",
		'abstract' => "yes",
		'inherits' => "yes",
		'args' => $arguments };

sub new {
    my ($class) = shift (@_);
    my ($pluginlist,$inputargs,$hashArgOptLists) = @_;
    push(@$pluginlist, $class);

    push(@{$hashArgOptLists->{"ArgList"}},@{$arguments});
    push(@{$hashArgOptLists->{"OptList"}},$options);

    my $self = new BaseMediaConverter($pluginlist, $inputargs, $hashArgOptLists, 1);

    # Set controlling variables
    my $gsdl_home = $ENV{'GSDLHOME'};
    my $music_ir_home = $ENV{'GEXT_MUSICIR'};

    return bless $self, $class;
}

sub retrieve_metadata
{
    my $self = shift(@_);
    my ($source_file_path,$id3_title,$id3_artist,$convert_options) = @_;

    $convert_options = "" if (!defined $convert_options);

    my $outhandle = $self->{'outhandle'};
    my $verbosity = $self->{'verbosity'};

    my $source_file_no_path = &File::Basename::basename($source_file_path);

    $self->init_cache_for_file($source_file_path);

    my $target_file_path;
    if ($self->{'enable_cache'}) {
	my $cached_dir = $self->{'cached_dir'};
	my $file_root = $self->{'cached_file_root'};

	my $target_file = "${file_root}_metadata.txt";

	$target_file_path = &util::filename_cat($cached_dir,$target_file);
    }
    else {
	$target_file_path = &util::get_tmp_filename("_metadata.txt");
    }

    my $jsongminer_cmd = "java -Xmx1024M -jar jSongMinor.jar $convert_options \"$id3_title\" \"$id3_artist\"";
		
    print STDERR "*** cmd: $jsongminer_cmd\n";

    my $print_info = { 'message_prefix' => "jSongMiner",
		       'message' => "Retrieving audio metadata for $source_file_no_path" };
	
#    my ($regenerated,$result,$had_error) 
#	= $self->autorun_general_cmd($jsongminer_cmd,$source_file_path,$target_file_path,$print_info);
	
    return ($target_file_path);
}
    



1;	
